@@ -199,13 +199,14 @@ eel_background_finalize (GObject *object)
 	g_free (background->details->gradient_buffer);
 	g_free (background->details->image_uri);
 	eel_background_remove_current_image (background);
-	g_free (background->details);
 
 	if (background->details->background_pixmap != NULL) {
 		g_object_unref (background->details->background_pixmap);
 		background->details->background_pixmap = NULL;
 	}
-	
+
+	g_free (background->details);
+
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
@@ -480,7 +481,11 @@ eel_background_image_totally_obscures (EelBackground *background)
 static void
 eel_background_ensure_image_scaled (EelBackground *background, int dest_width, int dest_height)
 {
-	if (background->details->image == NULL) {
+	/* Avoid very bad gdk-pixbuf scaling behaviour on 1x1 (not yet
+	 * sized) windows and large backrounds
+	 */
+	if (background->details->image == NULL ||
+	    (dest_width == 1 && dest_height == 1)) {
 		background->details->image_rect_x = 0;
 		background->details->image_rect_y = 0;
 		background->details->image_rect_width = 0;
@@ -965,6 +970,7 @@ static void
 eel_background_start_loading_image (EelBackground *background, gboolean emit_appearance_change,
 				    gboolean load_async)
 {
+	GdkPixbuf *pixbuf;
 	background->details->emit_after_load = emit_appearance_change;
 
 	if (background->details->image_uri != NULL) {
@@ -975,7 +981,11 @@ eel_background_start_loading_image (EelBackground *background, gboolean emit_app
 											    background);
 		}
 		else {
-			eel_background_load_image_callback (0, eel_gdk_pixbuf_load (background->details->image_uri), background);
+			pixbuf = eel_gdk_pixbuf_load (background->details->image_uri);
+			eel_background_load_image_callback (0, pixbuf, background);
+
+			/* load_image_callback refs the pixbuf so we unref it here */
+			g_object_unref (pixbuf);
 		}
 	} else {
 		eel_background_load_image_callback (0, NULL, background);
