@@ -365,8 +365,9 @@ eel_canvas_rect_realize (GnomeCanvasItem *item)
 {
 	EelCanvasRect *rect;
 	EelCanvasRectDetails *details;
+#ifdef HAVE_RENDER
 	int event_base, error_base;
-
+#endif
 	rect = EEL_CANVAS_RECT (item);
 	details = rect->details;
 	
@@ -387,6 +388,10 @@ eel_canvas_rect_realize (GnomeCanvasItem *item)
 		details->format = XRenderFindVisualFormat (dpy, visual);
 	}
 #endif
+
+	if (parent_class->realize) {
+		(* parent_class->realize) (item);
+	}
 }
 
 static void
@@ -407,6 +412,10 @@ eel_canvas_rect_unrealize (GnomeCanvasItem *item)
 		g_object_unref (details->fill_gc);
 		details->fill_gc = NULL;
 	}
+
+	if (parent_class->unrealize) {
+		(* parent_class->unrealize) (item);
+	}
 }
 
 static void
