@@ -59,7 +59,6 @@ gboolean    eel_g_list_exactly_one_item                 (GList                 *
 gboolean    eel_g_list_more_than_one_item               (GList                 *list);
 gboolean    eel_g_list_equal                            (GList                 *list_a,
 							 GList                 *list_b);
-GList *     eel_g_list_copy                             (GList                 *list);
 gboolean    eel_g_lists_sort_and_check_for_intersection (GList                **list_a,
 							 GList                **list_b);
 GList *     eel_g_list_partition                        (GList                 *list,
@@ -89,6 +88,12 @@ gboolean    eel_g_str_list_equal                        (GList                 *
 GList *     eel_g_str_list_copy                         (GList                 *str_list);
 GList *     eel_g_str_list_alphabetize                  (GList                 *str_list);
 
+/* List functions for lists of objects */
+GList *     eel_g_object_list_ref                       (GList                 *list);
+void        eel_g_object_list_unref                     (GList                 *list);
+void        eel_g_object_list_free                      (GList                 *list);
+GList *     eel_g_object_list_copy                      (GList                 *list);
+
 /* GHashTable functions */
 GHashTable *eel_g_hash_table_new_free_at_exit           (GHashFunc              hash_function,
 							 GCompareFunc           key_compare_function,
@@ -97,13 +102,6 @@ void        eel_g_hash_table_safe_for_each              (GHashTable            *
 							 GHFunc                 callback,
 							 gpointer               callback_data);
 
-/* GPtrArray functions */
-GPtrArray * eel_g_ptr_array_new_from_list               (GList                 *list);
-int         eel_g_ptr_array_search                      (GPtrArray             *array,
-							 EelSearchFunction      search_callback,
-							 gpointer               callback_data,
-							 gboolean               match_only);
-
 /* NULL terminated string arrays (strv). */
 int         eel_g_strv_find                             (char                 **strv,
 							 const char            *find_me);
@@ -124,4 +122,8 @@ int         eel_compare_integer                         (gconstpointer
 /* Return the operating system name: Linux, Solaris, etc. */
 char *      eel_get_operating_system_name               (void);
 
+/* Better weak pointer functions */
+void        eel_add_weak_pointer                        (gpointer               pointer_location);
+void        eel_remove_weak_pointer                     (gpointer               pointer_location);
+
 #endif /* EEL_GLIB_EXTENSIONS_H */
