@@ -554,7 +554,8 @@ static void
 preferences_item_update_editable_integer (EelPreferencesItem *item)
 {
 	char *current_value;
-
+	char *tmp;
+	
 	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (item));
 	g_return_if_fail (item->details->item_type == EEL_PREFERENCE_ITEM_EDITABLE_INTEGER);
 
@@ -562,12 +563,12 @@ preferences_item_update_editable_integer (EelPreferencesItem *item)
 
 	g_assert (current_value != NULL);
 
-	if (strcmp (eel_text_caption_get_text (EEL_TEXT_CAPTION (item->details->main_child)),
-		    current_value) != 0) {
+	tmp = eel_text_caption_get_text (EEL_TEXT_CAPTION (item->details->main_child));
+	if (strcmp (tmp, current_value) != 0) {
 		eel_text_caption_set_text (EEL_TEXT_CAPTION (item->details->main_child), 
 					   current_value);
 	}
-
+	g_free (tmp);
 	g_free (current_value);
 }
 
