@@ -228,9 +228,18 @@ eel_text_caption_set_editable (EelTextCaption *text_caption,
 
 void
 eel_text_caption_set_expand_tilde (EelTextCaption *text_caption,
-					gboolean expand_tilde)
+				   gboolean         expand_tilde)
 {
 	g_return_if_fail (EEL_IS_TEXT_CAPTION (text_caption));
 
 	text_caption->detail->expand_tilde = expand_tilde;
 }
+
+void
+eel_text_caption_set_visibility (EelTextCaption *text_caption,
+				 gboolean        visible)
+{
+	g_return_if_fail (EEL_IS_TEXT_CAPTION (text_caption));
+
+	gtk_entry_set_visibility (GTK_ENTRY (text_caption->detail->text), visible);
+}
